"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createHydrationEnvService = exports.setDefaultHydratingEnvService = exports.hasDefaultHydrationEnvService = exports.getDefaultHydrationEnvService = void 0;
const retil_mount_1 = require("retil-mount");
const retil_source_1 = require("retil-source");
const retil_support_1 = require("retil-support");
const getDefaultHydrationEnvService = () => {
    if (!exports.getDefaultHydrationEnvService.value) {
        exports.getDefaultHydrationEnvService.value = createHydrationEnvService();
    }
    return exports.getDefaultHydrationEnvService.value;
};
exports.getDefaultHydrationEnvService = getDefaultHydrationEnvService;
const hasDefaultHydrationEnvService = () => {
    return !!exports.getDefaultHydrationEnvService.value;
};
exports.hasDefaultHydrationEnvService = hasDefaultHydrationEnvService;
const setDefaultHydratingEnvService = (value) => {
    exports.getDefaultHydrationEnvService.value = value;
};
exports.setDefaultHydratingEnvService = setDefaultHydratingEnvService;
function createHydrationEnvService(options = {}) {
    const browser = typeof window !== 'undefined';
    const { default: defaultHydrationService, disablePrecache = !browser } = options;
    const hasDefault = exports.hasDefaultHydrationEnvService();
    if (hasDefault && defaultHydrationService) {
        throw new Error('Could not override the default nav service.');
    }
    const [hydratingSource, setHydrating] = retil_source_1.createState(retil_mount_1.createEnvVector(disablePrecache ? [true] : [true, false]));
    const hydratingEnvSource = retil_mount_1.fuseEnvSource((use) => ({
        hydrating: use(hydratingSource),
    }));
    const hydrate = browser ? () => setHydrating(retil_mount_1.createEnvVector([false])) : retil_support_1.noop;
    const service = [hydratingEnvSource, hydrate];
    if (!hasDefault &&
        (defaultHydrationService || defaultHydrationService === undefined)) {
        exports.setDefaultHydratingEnvService(service);
    }
    return service;
}
exports.createHydrationEnvService = createHydrationEnvService;
