import { createEnvVector, fuseEnvSource } from 'retil-mount';
import { createState } from 'retil-source';
import { noop } from 'retil-support';
export const getDefaultHydrationEnvService = () => {
    if (!getDefaultHydrationEnvService.value) {
        getDefaultHydrationEnvService.value = createHydrationEnvService();
    }
    return getDefaultHydrationEnvService.value;
};
export const hasDefaultHydrationEnvService = () => {
    return !!getDefaultHydrationEnvService.value;
};
export const setDefaultHydratingEnvService = (value) => {
    getDefaultHydrationEnvService.value = value;
};
export function createHydrationEnvService(options = {}) {
    const browser = typeof window !== 'undefined';
    const { default: defaultHydrationService, disablePrecache = !browser } = options;
    const hasDefault = hasDefaultHydrationEnvService();
    if (hasDefault && defaultHydrationService) {
        throw new Error('Could not override the default nav service.');
    }
    const [hydratingSource, setHydrating] = createState(createEnvVector(disablePrecache ? [true] : [true, false]));
    const hydratingEnvSource = fuseEnvSource((use) => ({
        hydrating: use(hydratingSource),
    }));
    const hydrate = browser ? () => setHydrating(createEnvVector([false])) : noop;
    const service = [hydratingEnvSource, hydrate];
    if (!hasDefault &&
        (defaultHydrationService || defaultHydrationService === undefined)) {
        setDefaultHydratingEnvService(service);
    }
    return service;
}
